@@ -126,7 +126,7 @@ enum {
 class R_dissimilarity {
 private:
   t_float * Xa;
-  long_index dim;
+  ssize_t dim; // ssize_t saves many statis_cast<> in products
   int * members;
   void (cluster_result::*postprocessfn) (const t_float) const;
   t_float postprocessarg;
@@ -149,6 +149,7 @@ public:
     : Xa(X),
       dim(dim),
       members(members),
+      postprocessfn(NULL),
       postprocessarg(p),
       N(N)
   {
@@ -467,7 +468,7 @@ extern "C" {
       const int N = *INTEGER_POINTER(N_);
       if (N<2)
         Rf_error("N must be at least 2.");
-      const long_index NN = static_cast<long_index>(N)*(N-1)/2;
+      const ssize_t NN = static_cast<ssize_t>(N)*(N-1)/2;
       UNPROTECT(1); // N_
 
       // Parameter method: dissimilarity index update method
@@ -509,7 +510,7 @@ extern "C" {
       auto_array_ptr<double> D__;
       if (method!=METHOD_METR_SINGLE) {
         D__.init(NN);
-        for (long_index i=0; i<NN; i++)
+        for (ssize_t i=0; i<NN; i++)
           D__[i] = D[i];
       }
       UNPROTECT(1); // D_
@@ -647,8 +648,8 @@ extern "C" {
       // to C-contiguous style
       // (Waste of memory for 'single'; the other methods need a copy
       auto_array_ptr<double> X(LENGTH(X_));
-      for (long_index i=0; i<N; i++)
-        for (long_index j=0; j<dim; j++)
+      for (ssize_t i=0; i<N; i++)
+        for (ssize_t j=0; j<dim; j++)
           X[i*dim+j] = X__[i+j*N];
 
       UNPROTECT(2); // dims_, X_
